]> git.mxchange.org Git - friendica.git/blobdiff - index.php
remove javascript to set selectect nav item. enanche img template prefetch ignoring
[friendica.git] / index.php
index 685a76a13185e26baf02960e43bf2e4a17896776..51c87cae6e6feff8b7f4abee66c6a4a61a76f635 100644 (file)
--- a/index.php
+++ b/index.php
@@ -19,22 +19,15 @@ $a = new App;
 /**
  *
  * Load the configuration file which contains our DB credentials.
- * Ignore errors. If the file doesn't exist, we are running in installation mode.
+ * Ignore errors. If the file doesn't exist or is empty, we are running in installation mode.
  *
  */
 
-$install = ((file_exists('.htconfig.php')) ? false : true);
+$install = ((file_exists('.htconfig.php') && filesize('.htconfig.php')) ? false : true);
 
 @include(".htconfig.php");
 
-/**
- *
- * Get the language setting directly from system variables, bypassing get_config()
- * as database may not yet be configured.
- *
- */
-
-$lang = ((isset($a->config['system']['language'])) ? $a->config['system']['language'] : 'en');
+$lang = get_language();
        
 load_translation_table($lang);
 
@@ -49,6 +42,21 @@ $db = new dba($db_host, $db_user, $db_pass, $db_data, $install);
         unset($db_host, $db_user, $db_pass, $db_data);
 
 
+if(! $install) {
+
+       /**
+        * Load configs from db. Overwrite configs from .htconfig.php
+        */
+
+       load_config('config');
+       load_config('system');
+
+       require_once("session.php");
+       load_hooks();
+       call_hooks('init_1');
+}
+
+
 /**
  *
  * Important stuff we always need to do.
@@ -61,14 +69,6 @@ $db = new dba($db_host, $db_user, $db_pass, $db_data, $install);
  *
  */
 
-if(! $install) {
-       require_once("session.php");
-       load_hooks();
-       call_hooks('init_1');
-}
-
-
-
 require_once("datetime.php");
 
 $a->timezone = (($default_timezone) ? $default_timezone : 'UTC');
@@ -79,6 +79,19 @@ $a->init_pagehead();
 
 session_start();
 
+/**
+ * Language was set earlier, but we can over-ride it in the session.
+ * We have to do it here because the session was just now opened.
+ */
+
+if(x($_POST,'system_language'))
+       $_SESSION['language'] = $_POST['system_language'];
+if((x($_SESSION,'language')) && ($_SESSION['language'] !== $lang)) {
+       $lang = $_SESSION['language'];
+       load_translation_table($lang);
+}
+
+
 /**
  *
  * For Mozilla auth manager - still needs sorting, and this might conflict with LRDD header.
@@ -101,9 +114,13 @@ if(! x($_SESSION,'authenticated'))
 if(! x($_SESSION,'sysmsg'))
        $_SESSION['sysmsg'] = '';
 
+if(! x($_SESSION,'sysmsg_info'))
+       $_SESSION['sysmsg_info'] = '';
+
 /*
* check_config() is responible for running update scripts. These automatically 
* update the DB schema whenever  we push a new one out. 
  */
 
 
@@ -113,9 +130,16 @@ else
        check_config($a);
 
 
+$arr = array('app_menu' => $a->apps);
+
+call_hooks('app_menu', $arr);
+
+$a->apps = $arr['app_menu'];
+
+
 /**
  *
- * We have already parsed the server path into $->argc and $a->argv
+ * We have already parsed the server path into $a->argc and $a->argv
  *
  * $a->argv[0] is our module name. We will load the file mod/{$a->argv[0]}.php
  * and use it for handling our URL request.
@@ -123,7 +147,7 @@ else
  * and in the following order:
  * 
  * "module"_init
- * "module"_post (only if there are $_POST variables)
+ * "module"_post (only called if there are $_POST variables)
  * "module"_afterpost
  * "module"_content - the string return of this function contains our page body
  *
@@ -132,24 +156,63 @@ else
  * further processing.
  */
 
-
 if(strlen($a->module)) {
-       if(file_exists("mod/{$a->module}.php")) {
-               include("mod/{$a->module}.php");
+
+       /**
+        *
+        * We will always have a module name.
+        * First see if we have a plugin which is masquerading as a module.
+        *
+        */
+
+       if(is_array($a->plugins) && in_array($a->module,$a->plugins) && file_exists("addon/{$a->module}/{$a->module}.php")) {
+               include_once("addon/{$a->module}/{$a->module}.php");
+               if(function_exists($a->module . '_module'))
+                       $a->module_loaded = true;
+       }
+
+       /**
+        * If not, next look for a 'standard' program module in the 'mod' directory
+        */
+
+       if((! $a->module_loaded) && (file_exists("mod/{$a->module}.php"))) {
+               include_once("mod/{$a->module}.php");
                $a->module_loaded = true;
        }
-       else {
+
+       /**
+        *
+        * The URL provided does not resolve to a valid module.
+        *
+        * On Dreamhost sites, quite often things go wrong for no apparent reason and they send us to '/internal_error.html'. 
+        * We don't like doing this, but as it occasionally accounts for 10-20% or more of all site traffic - 
+        * we are going to trap this and redirect back to the requested page. As long as you don't have a critical error on your page
+        * this will often succeed and eventually do the right thing.
+        *
+        * Otherwise we are going to emit a 404 not found.
+        *
+        */
+
+       if(! $a->module_loaded) {
+
+               // Stupid browser tried to pre-fetch our Javascript img template. Don't log the event or return anything - just quietly exit.
+               if((x($_SERVER,'QUERY_STRING')) && preg_match('/{[0-9]}/',$_SERVER['QUERY_STRING']) !== 0) {
+                       killme();
+               }
+
                if((x($_SERVER,'QUERY_STRING')) && ($_SERVER['QUERY_STRING'] === 'q=internal_error.html') && isset($dreamhost_error_hack)) {
                        logger('index.php: dreamhost_error_hack invoked. Original URI =' . $_SERVER['REQUEST_URI']);
                        goaway($a->get_baseurl() . $_SERVER['REQUEST_URI']);
                }
 
-               logger('index.php: page not found: ' . $_SERVER['REQUEST_URI'] . ' QUERY: ' . $_SERVER['QUERY_STRING'], LOGGER_DEBUG);
+               logger('index.php: page not found: ' . $_SERVER['REQUEST_URI'] . ' ADDRESS: ' . $_SERVER['REMOTE_ADDR'] . ' QUERY: ' . $_SERVER['QUERY_STRING'], LOGGER_DEBUG);
                header($_SERVER["SERVER_PROTOCOL"] . ' 404 ' . t('Not Found'));
                notice( t('Page not found.' ) . EOL);
        }
 }
 
+
+
 /* initialise content region */
 
 if(! x($a->page,'content'))
@@ -186,7 +249,7 @@ if($a->module_loaded) {
 
 }
 
-// let javascript take you home
+// If you're just visiting, let javascript take you home
 
 if(x($_SESSION,'visitor_home'))
        $homebase = $_SESSION['visitor_home'];
@@ -212,8 +275,16 @@ if(stristr($_SESSION['sysmsg'], t('Permission denied'))) {
 if(x($_SESSION,'sysmsg')) {
        $a->page['content'] = "<div id=\"sysmsg\" class=\"error-message\">{$_SESSION['sysmsg']}</div>\r\n"
                . ((x($a->page,'content')) ? $a->page['content'] : '');
+       $_SESSION['sysmsg']="";
        unset($_SESSION['sysmsg']);
 }
+if(x($_SESSION,'sysmsg_info')) {
+       $a->page['content'] = "<div id=\"sysmsg_info\" class=\"info-message\">{$_SESSION['sysmsg_info']}</div>\r\n"
+               . ((x($a->page,'content')) ? $a->page['content'] : '');
+       $_SESSION['sysmsg_info']="";
+       unset($_SESSION['sysmsg_info']);
+}
+
 
 
 call_hooks('page_end', $a->page['content']);
@@ -234,25 +305,15 @@ $a->page['content'] .=  '<div id="pause"></div>';
  *
  */
 
-if($a->module != 'install')
-       require_once('nav.php');
+if($a->module != 'install') {
+       nav($a);
+}
 
 /**
- *
  * Build the page - now that we have all the components
- * Make sure the desired theme exists, though if the default theme doesn't exist we're stuffed.
- *
  */
 
-$default_theme = ((isset($a->config['system']['theme'])) ? $a->config['system']['theme'] : 'default');
-if((x($_SESSION,'theme')) && (! file_exists('view/theme/' . $_SESSION['theme'] . '/style.css')))
-       unset($_SESSION['theme']);
-
-$a->page['htmlhead'] = replace_macros($a->page['htmlhead'], array(
-       '$stylesheet' => $a->get_baseurl() . '/view/theme/'
-               . ((x($_SESSION,'theme')) ? $_SESSION['theme'] : $default_theme)
-               . '/style.css'
-       ));
+$a->page['htmlhead'] = replace_macros($a->page['htmlhead'], array('$stylesheet' => current_theme_url()));
 
 $page    = $a->page;
 $profile = $a->profile;
@@ -101,9 +114,13 @@ if(! x($_SESSION,'authenticated'))
 /*
- * check_config() is responible for running update scripts. These automatically 
- * update the DB schema whenever  we push a new one out. 
+ * check_config() is responsible for running update scripts. These automatically 
+ * update the DB schema whenever we push a new one out. It also checks to see if
+ * any plugins have been added or removed and reacts accordingly. 
  */
 